==> qt-creator-opensource-src-4.7.1.zip: qt-creator-opensource-src-4.7.1/src/libs/clangsupport/projectmanagementserverinterface.h <==
/****************************************************************************
**
** Copyright (C) 2017 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "ipcserverinterface.h"

namespace ClangBackEnd {

class RemoveProjectPartsMessage;
class UpdateProjectPartsMessage;

class ProjectManagementServerInterface : public IpcServerInterface
{
public:
    virtual void updateProjectParts(UpdateProjectPartsMessage &&message) = 0;
    virtual void removeProjectParts(RemoveProjectPartsMessage &&message) = 0;

protected:
    ~ProjectManagementServerInterface() = default;
};

} // namespace ClangBackEnd

==> qt-creator-opensource-src-4.12.3.zip: qt-creator-opensource-src-4.12.3/src/libs/clangsupport/projectmanagementserverinterface.h <==
/****************************************************************************
**
** Copyright (C) 2017 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "ipcserverinterface.h"

namespace ClangBackEnd {

class RemoveGeneratedFilesMessage;
class RemoveProjectPartsMessage;
class UpdateGeneratedFilesMessage;
class UpdateProjectPartsMessage;

class ProjectManagementServerInterface : public IpcServerInterface
{
public:
    virtual void updateProjectParts(UpdateProjectPartsMessage &&message) = 0;
    virtual void removeProjectParts(RemoveProjectPartsMessage &&message) = 0;
    virtual void updateGeneratedFiles(UpdateGeneratedFilesMessage &&message) = 0;
    virtual void removeGeneratedFiles(RemoveGeneratedFilesMessage &&message) = 0;
};

} // namespace ClangBackEnd
